@@ -1,4 +1,4 @@
-from . import _spider_abc as abc
+from . import _abc as abc
 from . import db
 from . import io
 from . import static
